API Reference
=============

.. toctree::
    :maxdepth: 5

    xarray/index
    extractor/index
    timeseries/index
    visual/index
    viewer/index
    particles/index
    geometry/index

    .. geometry/index
    .. extractor/index
    .. particles/index
    .. timeseries/index
    .. viewer/index
    .. visual/index
    .. xarray/index
    
